@@ -9,9 +9,15 @@ vxapi
 """
 
 __title__ = 'vxapi'
-__version__ = '0.0.2'
+__version__ = '0.0.4'
 __author__ = 'Anthony Wu'
 __license__ = 'MIT License'
 __copyright__ = 'Copyright 2014 Anthony Wu'
 
-from .api import VirginAmericaWebSession
+try:
+	from .api import VirginAmericaWebSession
+except ImportError:
+	# during initial pip install setup, this file will be read for the metadata properties
+	# at that time, not all dependencies have been installed, and this will fail
+	# but that's okay
+	pass
